<?php

class NewsletterSignups {

/**
 * Signup a user to the newsletter. This encodes the extra fields so it doesn't need to be done before hand.
 *
 * @param array $data The array of the signup. Keys should be email and extras. The extras are json_encoded.
 * @return array the key status holds success or error, if it's an error, errors will be created
 */
	public function signup($data) {
		// check for extras
		$extraFields = Configure::read('EvNewsletterSignups.extraFields');
		$signupData = [
			'email' => $data['email'],
			'extras' => []
		];
		if (!empty($data['extras']) && !empty($extraFields)) {
			$signupData['extras'] = json_encode($data['extras']);
		}
		$Signup = EvClassRegistry::init('EvNewsletterSignups.Signup');
		if ($Signup->save($signupData)) {
			return [
				'status' => 'success'
			];
		} else {
			return [
				'status' => 'error',
				'errors' => $Signup->validationErrors,
			];
		}
	}

/**
 * Pass an array of data through to get formatted correctly for signups.
 *
 * @param array $data        The data to format. Must include email as a top level key.
 * @param array $extraFields Fields to resitct to the extras. Left empty all will be added. If set to false none will be added.
 * @return array The formatted data.
 */
	public function formatSignupData($data, $extraFields = []) {
		$signupData = [];

		if (!isset($data['email'])) {
			return false;
		}

		$signupData['email'] = $data['email'];

		if (isset($data['extras'])) {
			$signupData['extras'] = $data['extras'];
		} else {
			unset($data['email']);

			$extraData = [];

			if (is_array($extraFields) && !empty($extraFields)) {
				foreach ($data as $field => $value) {
					//Check if the field is to be added to the extra data.
					if (in_array($field, $extraFields)) {
						$extraData[$field] = $value;
					}
				}
			} elseif ($extraFields !== false) {
				$extraData = $data;
			}

			$signupData['extras'] = $extraData;
		}

		return $signupData;
	}
}
